# Changelog

## 0.1.2

- Update project URLs in pyproject.toml

## 0.1.1

- Add Homepage, Changelog URLs to pyproject.toml

## 0.1.2

- Update project URLs in pyproject.toml

## 0.1.1

- Add project URLs to pyproject.toml

## 0.1.0 (2026-03-10)

- Initial release
- ASGI middleware for FastAPI/Starlette
- WSGI middleware for Flask/Django
- Slow request threshold warnings
- Server-Timing response header
